@@ -10,8 +10,13 @@ import secrets
 from typing import Any
 
 from starfish.agent.agent_base import AgentBase
-from starfish.ddo.ddo import DDO
+from starfish.asset import create_asset
 from starfish.listing import Listing
+from starfish.network.ddo import DDO
+from starfish.network.did import (
+    decode_to_asset_id,
+    did_generate_random
+)
 from starfish.purchase import Purchase
 from starfish.types import (
     ListingData,
@@ -19,10 +24,6 @@ from starfish.types import (
     TListing
 )
 from starfish.utils.crypto_hash import hash_sha3_256
-from starfish.utils.did import (
-    decode_to_asset_id,
-    did_generate_random
-)
 
 
 class MemoryAgent(AgentBase):
@@ -64,8 +65,8 @@ class MemoryAgent(AgentBase):
         asset_id = hash_sha3_256(asset.metadata_text)
         did = f'{self._ddo.did}/{asset_id}'
 
+        asset = create_asset(asset.metadata_text, did)
         self._memory['asset'][did] = asset
-        asset.set_did(did)
         return asset
 
     def create_listing(self, listing_data: ListingData, asset_did: str) -> TListing:
@@ -202,7 +203,7 @@ class MemoryAgent(AgentBase):
 
         if purchase_id in self._memory['purchase']:
             purchase, account_address = self._memory['purchase'][purchase_id]
-            return purchase and account.is_address_equal(account_address)
+            return purchase and account.address == account_address
 
         return False
 
