@@ -20,35 +20,33 @@ from urllib.parse import urljoin
 from eth_utils import remove_0x_prefix
 from mongoquery import Query
 
-from starfish.account import Account
 from starfish.agent.agent_base import AgentBase
-from starfish.agent.services import Services
 from starfish.asset import (
     DataAsset,
     OperationAsset,
-    create_asset_from_metadata_text,
+    create_asset,
     is_asset_hash_valid
 )
-from starfish.ddo.ddo import DDO
 from starfish.exceptions import (
     StarfishAssetInvalid,
     StarfishRemoteAgentInvalidAccess
 )
 from starfish.job import Job
 from starfish.listing import Listing
-from starfish.middleware.remote_agent_adapter import RemoteAgentAdapter
-from starfish.network import Network
+from starfish.middleware.agent.remote_agent_adapter import RemoteAgentAdapter
+from starfish.network.account_base import AccountBase
+from starfish.network.ddo import DDO
+from starfish.network.did import (
+    decode_to_asset_id,
+    did_parse
+)
+from starfish.network.network_base import NetworkBase
 from starfish.types import (
     Authentication,
     ListingData,
     TAsset,
     TRemoteAgent
 )
-from starfish.utils.did import (
-    decode_to_asset_id,
-    did_generate_random,
-    did_parse
-)
 
 SUPPORTED_SERVICES = {
     'meta': 'DEP.Meta.v1',
@@ -57,6 +55,7 @@ SUPPORTED_SERVICES = {
     'market': 'DEP.Market.v1',
     'trust': 'DEP.Trust.v1',
     'auth': 'DEP.Auth.v1',
+    'collection': 'DEP.Collection.v1',
 }
 
 
@@ -82,28 +81,27 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
     """
     service_types = SUPPORTED_SERVICES
 
-    def __init__(self, ddo: DDO, authentication: Authentication = None) -> None:
+    def __init__(self, ddo: DDO, authentication: Authentication = None, http_client: Any = None) -> None:
         self._authentication = authentication
 
-        if isinstance(ddo, dict):
-            ddo = DDO(dictionary=ddo)
-        elif isinstance(ddo, str):
-            ddo = DDO(json_text=ddo)
+        if isinstance(ddo, str):
+            ddo = DDO.import_from_text(ddo)
         elif isinstance(ddo, DDO):
             pass
         else:
             raise ValueError(f'Unknown ddo type {ddo}')
         AgentBase.__init__(self, ddo)
 
-        self._adapter = RemoteAgentAdapter()
+        self._adapter = RemoteAgentAdapter(http_client)
 
     @staticmethod
     def load(
         agent_did_or_url: str,
-        network: Network = None,
+        network: NetworkBase = None,
         username: str = None,
         password: str = None,
-        authentication: Authentication = None
+        authentication: Authentication = None,
+        http_client: Any = None
     ) -> TRemoteAgent:
         """
 
@@ -113,6 +111,7 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
 
         :param str agent_did_or_url DID or URL of the agent to load.
         :param Authentiaciton authentication Optional Authenentication object to use to access the new agent.
+        :param http_client: HTTP Client libray to use to make requests, this defaults to requests library.
 
         :return: A RemoteAgent Object or None if the agent cannot be accessed or cannot be found at the url.
 
@@ -128,15 +127,21 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         if network:
             ddo_text = network.resolve_agent(agent_did_or_url, authentication=authentication)
         else:
-            ddo_text = RemoteAgent.resolve_url(agent_did_or_url, authentication=authentication)
+            ddo_text = RemoteAgent.resolve_url(agent_did_or_url, authentication=authentication, http_client=http_client)
 
         if ddo_text:
-            return RemoteAgent(ddo_text, authentication)
+            return RemoteAgent(ddo_text, authentication=authentication, http_client=http_client)
 
         return None
 
     @staticmethod
-    def register(network: Network, register_account: Account, ddo: DDO, authentication: Authentication = None) -> TRemoteAgent:
+    def register(
+        network: NetworkBase,
+        register_account: AccountBase,
+        ddo: DDO,
+        authentication: Authentication = None,
+        http_client: Any = None
+    ) -> TRemoteAgent:
         """
         Register the agent on the network.
 
@@ -144,11 +149,12 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         :param register_account: Account object to use to register the agent ddo
         :param ddo: DDO object to use to register on the network
         :param authentication: Authentication data needed to access this agent
+        :param http_client: HTTP Client libray to use to make requests, this defaults to requests library.
 
         :return: RemoteAgent object that has been registered on the network
         """
-        network.register_did(register_account, ddo.did, ddo.as_text())
-        return RemoteAgent(ddo.as_text(), authentication)
+        network.register_did(register_account, ddo.did, ddo.as_text)
+        return RemoteAgent(ddo.as_text, authentication=authentication, http_client=http_client)
 
     def register_asset(self, asset: TAsset, create_provenance: bool = False) -> TAsset:
         """
@@ -186,7 +192,7 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
                     f' calculated asset_id {asset.asset_id} is not the same as the agent generated asset_id {asset_id}'
                 )
             did = f'{self._ddo.did}/{asset_id}'
-            asset.set_did(did)
+            asset = create_asset(asset.metadata_text, did=did, asset=asset)
         return asset
 
     def create_listing(self, listing_data: ListingData, asset_did: str) -> Listing:
@@ -284,9 +290,9 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         store_asset = self.get_asset(asset_id)
         asset = DataAsset(
             store_asset.metadata_text,
+            did=store_asset.did,
             data=data
         )
-        asset.set_did(store_asset.did)
         return asset
 
     def get_listing(self, listing_id: str) -> Listing:
@@ -421,7 +427,7 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         # TODO: implement search listing in remote
         pass
 
-    def purchase_asset(self, listing: Any, account: Any, purchase_id: str = None, status: str = None,
+    def purchase_asset(self, listing: Any, AccountBase: Any, purchase_id: str = None, status: str = None,
                        info: Any = None, agreement: Any = None) -> bool:
         """
 
@@ -543,6 +549,34 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         response = self._adapter.invoke(remove_0x_prefix(asset.asset_id), inputs, url, authorization_token)
         return response
 
+    def get_collection_items(self, name=None):
+        url = self.get_endpoint('collection')
+        if not url:
+            return None
+        authorization_token = self.get_authorization_token()
+        response = self._adapter.get_collection_items(url, name, authorization_token)
+        return response
+
+    def add_collection_items(self, name, asset_list):
+        if not isinstance(asset_list, (tuple, list)):
+            raise ValueError('You must pass a list of asset ids to add to the collection')
+        url = self.get_endpoint('collection')
+        if not url:
+            return None
+        authorization_token = self.get_authorization_token()
+        response = self._adapter.add_collection_items(url, name, asset_list, authorization_token)
+        return response
+
+    def remove_collection_items(self, name, asset_list):
+        if not isinstance(asset_list, (tuple, list)):
+            raise ValueError('You must pass a list of asset ids to remove from the collection')
+        url = self.get_endpoint('collection')
+        if not url:
+            return None
+        authorization_token = self.get_authorization_token()
+        response = self._adapter.remove_collection_items(url, name, asset_list, authorization_token)
+        return response
+
     def get_authorization_token(self) -> str:
 
         if self._authentication and 'token' in self._authentication:
@@ -614,69 +648,6 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
         data = did_parse(did)
         return data['path'] and data['id_hex']
 
-    @staticmethod
-    def generate_ddo(
-        base_url_or_services: Any,
-        service_list: Any = None,
-        all_services: bool = False,
-        is_add_proof: bool = False
-    ) -> DDO:
-        """
-        Generate a DDO for the remote agent url. This DDO will contain the supported
-        endpoints for the remote agent
-
-        :param str base_url_or_services: Base URL of the remote agent
-        :param dict base_url_or_services: Service dict to use. This has to be in the sample format:
-            see starfish.agent.services SERVICES
-
-        :param :class:`agent.services.Services` base_url_or_services: An agent Services object.
-
-        :param dict service_list: Optional list of services to regsiter. This is only if the
-            base_url_or_services is a string containing the base_url.
-
-        :param bool all_services: Optional False, If set to True register all available services.
-        :param bool is_add_proof: Optional False, If True add a proof signature to the ddo.
-
-        :return: created DDO object assigned to the url of the remote agent service
-        :type: :class:.`DDO`
-
-            generate_ddo('http://localhost', ['metadata', 'storage'])
-
-            # is the same as
-            services = Services('http://localhost', service_list=['metadata', 'storage'])
-            generate_ddo(services)
-
-            # or
-
-            generate_ddo(services.as_dict)
-
-        """
-
-        service_items = None
-
-        if isinstance(base_url_or_services, str):
-            services = Services(base_url_or_services, service_list, all_services=all_services)
-            service_items = services.as_dict
-        elif isinstance(base_url_or_services, dict):
-            service_items = base_url_or_services
-        elif isinstance(base_url_or_services, Services):
-            service_items = base_url_or_services.as_dict
-        else:
-            raise(TypeError('Invalid services type, must be a string, dict or Services object'))
-
-        did = did_generate_random()
-        ddo = DDO(did)
-        for _service_name, service_item in service_items.items():
-            ddo.add_service(service_item['type'], service_item['url'], None)
-
-        if is_add_proof:
-            # add a signature
-            private_key_pem = ddo.add_signature()
-            # add the static proof
-            ddo.add_proof(0, private_key_pem)
-
-        return ddo
-
     def _create_asset_from_read(self, asset_id: str, read_metadata: Any) -> Any:
         # check the hash of the reading asset
         asset_id = remove_0x_prefix(asset_id)
@@ -685,12 +656,21 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
 
         did = f'{self._ddo.did}/{asset_id}'
         metadata_text = read_metadata['metadata_text']
-        asset = create_asset_from_metadata_text(metadata_text)
-        asset.set_did(did)
+        asset = create_asset(metadata_text, did)
         return asset
 
+    def is_service(self, name):
+        service_type = RemoteAgent.find_supported_service_type(name)
+        if service_type is None:
+            message = f'unknown surfer endpoint service name or type: {name}'
+            logger.error(message)
+            raise ValueError(message)
+        service = self._ddo.get_service_type(service_type)
+        return service is not None
+
     def get_endpoint(self, name: str, uri: str = None) -> str:
         """return the endpoint based on the name of the service or service type"""
+
         service_type = RemoteAgent.find_supported_service_type(name)
         if service_type is None:
             message = f'unknown surfer endpoint service name or type: {name}'
@@ -699,12 +679,12 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
 
         endpoint = None
         if self._ddo:
-            service = self._ddo.get_service(service_type)
-            if not service:
+            service_item = self._ddo.get_service_type(service_type)
+            if not service_item:
                 message = f'unable to find surfer endpoint service type {service_type}'
                 logger.error(message)
                 raise ValueError(message)
-            endpoint = service.endpoint
+            endpoint = service_item['serviceEndpoint']
         if not endpoint:
             message = f'unable to find surfer endpoint for {name} = {service_type}'
             logger.error(message)
@@ -713,30 +693,51 @@ class RemoteAgent(AgentBase, Generic[TRemoteAgent]):
             endpoint = urljoin(endpoint + '/', uri)
         return endpoint
 
+    @property
+    def adapter(self):
+        return self._adapter
+
+    @property
+    def authentication(self):
+        return self._authentication
+
+    @property
+    def http_client(self):
+        return self._adapter.http_client
+
+    @http_client.setter
+    def http_client(self, value):
+        """Set the http client to something other than the default `requests`"""
+        self._adapter.http_client = value
+
     @staticmethod
-    def resolve_url(url: str, authentication: Authentication = None) -> DDO:
+    def resolve_url(url: str, authentication: Authentication = None, http_client: Any = None) -> DDO:
         """
 
         Resolves the remote agent ddo using the url of the agent
 
         :param str url: url of the remote agent
-        :param str username: optional username for access to the remote agent
-        :param str password: optional password for access to the remote agent
+        :param Authenentication: Optional authentication object to access the agent
+        :param http_client: HTTP Client libray to use to make requests, this defaults to requests library.
+
         :return dict: DDO or None if not found
         """
 
         ddo = None
         if url:
-            adapter = RemoteAgentAdapter()
+            adapter = RemoteAgentAdapter(http_client)
             token = None
-            token_url = urljoin(f'{url}/', 'api/v1/auth/token')
-            if authentication and 'username' in authentication:
-                token = adapter.get_authorization_token(
-                    authentication['username'],
-                    authentication.get('password', ''),
-                    token_url
-                )
-
+            # try to get a token from the agent using the username/password, or from the authentication dict
+            if authentication:
+                if 'username' in authentication and authentication['username']:
+                    token_url = urljoin(f'{url}/', 'api/v1/auth/token')
+                    token = adapter.get_authorization_token(
+                        authentication['username'],
+                        authentication.get('password', ''),
+                        token_url
+                    )
+                elif 'token' in authentication and authentication['token']:
+                    token = authentication['token']
             ddo = adapter.get_ddo(url, token)
         return ddo
 
