@@ -3,18 +3,22 @@
     RemoteDataAsset:  DataAsset that has only a URL for assigned in the metadada
 
 """
-
 from mimetypes import MimeTypes
+from typing import (
+    Any,
+    Generic
+)
 from urllib.parse import urlparse
 
 from starfish.asset.asset_base import AssetBase
 from starfish.asset.data_asset import DataAsset
+from starfish.types import TRemoteDataAsset
 
 
-class RemoteDataAsset(DataAsset):
+class RemoteDataAsset(DataAsset, Generic[TRemoteDataAsset]):
 
     @staticmethod
-    def create_with_url(name, url, metadata=None, did=None):
+    def create_with_url(name: str, url: str, metadata: Any = None, did: str = None) -> TRemoteDataAsset:
         """
 
         Create a new RemoteDataAsset using a url.
@@ -41,7 +45,7 @@ class RemoteDataAsset(DataAsset):
         return RemoteDataAsset(metadata, did)
 
     @property
-    def url(self):
+    def url(self) -> str:
         if 'url' in self._metadata:
             return self._metadata['url']
         return None
