@@ -5,9 +5,10 @@
 
 """
 import logging
+import os
 from typing import Any
 
-from starfish.account import Account
+from starfish.network.convex.convex_account import ConvexAccount
 from .command_base import CommandBase
 
 logger = logging.getLogger(__name__)
@@ -38,14 +39,19 @@ class AccountCreateCommand(CommandBase):
         return parser
 
     def execute(self, args: Any, output: Any) -> None:
-        account = Account.create(args.password)
+        network = self.get_network(args.url)
+        base_account = None
+        if args.password and args.keyfile:
+            base_account = ConvexAccount.import_from_file(args.keyfile, args.password)
+        account = network.create_account(base_account)
         logger.debug(f'create new account {account.address}')
-        if args.keyfile:
+        if args.keyfile and not os.path.exists(args.keyfile):
             logger.debug(f'writing key file to {args.keyfile}')
-            account.save_to_file(args.keyfile)
+            account.export_to_file(args.keyfile, args.password)
         else:
             logger.debug('writing key file to ouptut')
-            output.add_line(account.export_key_value)
+            output.add_line(account.export_to_text(args.password))
         output.add_line(account.address)
-        output.set_value('keyvalue', account.key_value)
+        output.set_value('public_key', account.public_key)
+        output.set_value('export_key', account.export_to_text(args.password))
         output.set_value('address', account.address)
