@@ -3,20 +3,21 @@ import pytest
 import secrets
 
 from tests.unit.libs.unit_test_config import unitTestConfig
-from tests.unit.libs.unit_test_network import UnitTestNetwork
 
 @pytest.fixture(scope="module")
 def config():
     return unitTestConfig
 
+"""
 @pytest.fixture(scope="module")
-def network(config):
-    network = UnitTestNetwork(config.network_url)
+def ethereum_network(config):
+    network = UnitTestNetwork(config.ethereum.network_url)
     return network
 
 @pytest.fixture(scope='module')
-def accounts(config):
+def ethereum_accounts(config):
     accounts = []
-    for acount_info in config.accounts:
+    for acount_info in config.ethereum.accounts:
         accounts.append(Account(account_info.as_dict))
     return accounts
+"""
